@@ -1,6 +1,6 @@
 <?php
 // 
-// $Id: ezpublish.php,v 1.14.2.9 2003/04/11 15:11:50 br Exp $
+// $Id: ezpublish.php 9846 2003-06-05 11:01:48Z br $
 //
 // Definition of eZPublish class
 //
@@ -40,8 +40,31 @@ class eZPublish
     */
     function version()
     {
-        return "2.2.8";
+        return "2.3.0";
     }
+
+    /*!
+      \static
+      Returns the eZ publish svn version number.
+      This function is currently static, it will need to become dynamic 
+      to check an external source and return the actual dynamic svn number
+    */
+    function svnVersion()
+    {
+	//        return "2.2.9";
+	return "trunk_1";
+    }
+
+    /*!
+      \static
+      Returns the eZ publish installation version number.
+    */
+    function installationVersion()
+    {
+        //        return "2.2.9";
+        return "0.0.4";
+    }
+
 }
 
 ?>
