@@ -1,6 +1,6 @@
 <?php
 // 
-// $Id: eztemplate.php,v 1.46.2.8 2002/04/25 09:28:35 jhe Exp $
+// $Id: eztemplate.php 9474 2002-04-25 09:28:35Z jhe $
 //
 // Definition of eZTemplate class
 //
@@ -443,8 +443,10 @@ class eZTemplate
         if ( !is_array( $handle ) )
         {
             if ( $filename == "" )
-            {
-                $this->halt( "set_file: For handle $handle filename is empty." );
+	      { 
+                // kracker : Added Support for template filename error tracking
+                $phpFile = $this->phpFile;
+                $this->halt( "set_file ($phpFile): For handle $handle filename is empty." ); 
                 return false;
             }
             $this->file[$handle] = $this->filename( $filename );
