@@ -1,6 +1,6 @@
 <?php
 // 
-// $Id: articleview.php,v 1.84.2.14 2002/11/22 11:15:06 bf Exp $
+// $Id: articleview.php 9879 2003-07-24 08:47:34Z br $
 //
 // Created on: <18-Oct-2000 16:34:51 bf>
 //
@@ -38,14 +38,24 @@ $ini =& INIFile::globalINI();
 
 $Language = $ini->read_var( "eZArticleMain", "Language" );
 $ForceCategoryDefinition = $ini->read_var( "eZArticleMain", "ForceCategoryDefinition" );
-$CapitalizeHeadlines = $ini->read_var( "eZArticleMain", "CapitalizeHeadlines" );
 $TemplateDir = $ini->read_var( "eZArticleMain", "TemplateDir" );
+$CapitalizeHeadlines = $ini->read_var( "eZArticleMain", "CapitalizeHeadlines" );
 $ListImageWidth = $ini->read_var( "eZArticleMain", "ListImageWidth" );
 $ListImageHeight = $ini->read_var( "eZArticleMain", "ListImageHeight" );
 
+if ( !is_numeric( $ArticleID ) )
+{
+    eZHTTPTool::header( "Location: /error/404" );
+    exit();
+}
+
+if ( !is_numeric( $PageNumber) )
+    $PageNumber = "";
+
 if ( !is_numeric( $CategoryID ) )
     $CategoryID = eZArticle::categoryDefinitionStatic( $ArticleID );
 
+
 if ( $ForceCategoryDefinition == "enabled" )
 {
     $CategoryID = eZArticle::categoryDefinitionStatic( $ArticleID );
@@ -57,6 +67,11 @@ $GlobalSectionID = eZArticleCategory::sectionIDStatic( $CategoryID );
 $sectionObject =& eZSection::globalSectionObject( $GlobalSectionID );
 $sectionObject->setOverrideVariables();
 
+$templateDirTmp = $sectionObject->templateStyle();
+if ( trim( $templateDirTmp ) != "" )
+{
+    $TemplateDir = preg_replace( "/(.+)\/.+(\/?)/", "/\\1/$templateDirTmp\\2", $TemplateDir );
+}
 
 $t = new eZTemplate( "ezarticle/user/" . $TemplateDir,
                      "ezarticle/user/intl/", $Language, "articleview.php" );
