@@ -1,6 +1,6 @@
 <?php
 // 
-// $Id: ezmail.php,v 1.44.2.7 2002/06/10 16:41:45 fh Exp $
+// $Id: ezmail.php 9884 2003-08-21 10:12:50Z vl $
 //
 // Definition of eZMail class
 //
@@ -976,7 +976,59 @@ class eZMail
                     echo "Added attachment";
                     $filename = "ezfilemanager/files/" . $file->fileName();
                     $attachment = fread( eZFile::fopen( $filename, "r" ), eZFile::filesize( $filename ) );
-                    $this->add_attachment( $attachment, $file->originalFileName(), "image/jpeg" );
+                    // get the correct mime type.
+                    $suffix = strtolower( preg_replace( "/^.+\.(.+)$/", "\\1", $file->originalFileName() ) );
+                    $mimeType = "";
+                    switch ( $suffix )
+                    {
+                        case "doc":
+                            $mimeType = "application/msword";
+                        break;
+                        case "ppt":
+                            $mimeType = "application/vnd.ms-powerpoint";
+                        break;
+                        case "xls":
+                            $mimeType = "application/vnd.ms-excel";
+                        break;
+                        case "pdf":
+                            $mimeType = "application/pdf";
+                        break;
+                        
+                        case "jpg":
+                        case "jpeg":
+                            $mimeType = "image/jpeg";
+                        break;
+
+                        case "bz2":
+                            $mimeType = "application/x-bzip2";
+                        break;
+
+                        case "html":
+                        case "htm":
+                            $mimeType = "text/html";
+                        break;
+
+                        case "txt":
+                            $mimeType = "text/plain";
+                        break;
+
+                        case "gif":
+                            $mimeType = "image/gif";
+                        break;
+
+                        case "png":
+                            $mimeType = "image/png";
+                        break;
+
+                        case "zip":
+                            $mimeType = "application/zip";
+                        break;
+
+                        default:
+                            $mimeType = "application/octet-stream";
+                    }
+
+                    $this->add_attachment( $attachment, $file->originalFileName(), $mimeType );
                 }
             }
         }
@@ -984,6 +1036,7 @@ class eZMail
         $mime = "";
         if ( !empty( $this->From ) )
         {
+	    $envelope = "-f " . $this->From;
             if ( !empty( $this->FromName ) )
                 $mime .= "From: " . $this->FromName . " <" . $this->From . ">\n";
             else
@@ -1002,7 +1055,16 @@ class eZMail
         }
 
         $mime .= "MIME-Version: 1.0\n" . $this->build_multipart();
-        mail( $this->To, $this->Subject, "", $mime );
+
+	if ( isset ( $envelope ) )
+	{
+	    mail( $this->To, $this->Subject, "", $mime, $envelope );
+	} else
+	{
+            mail( $this->To, $this->Subject, "", $mime );
+	}
+
+
         $this->parts = array();
     }
     
