@@ -41,4 +41,4 @@ CREATE TABLE eZNewsFeed_SourceSite (
   PRIMARY KEY (ID)
 );
 
-INSERT INTO eZNewsFeed_SourceSite VALUES (1,'http://freshmeat.net/backend/fm.rdf','','',1,'Freshmeat','',0,0);
+INSERT INTO eZNewsFeed_SourceSite VALUES (1,'http://freshmeat.net/backend/fm.rdf','','',1,'Freshmeat','rdf',1,1);
